@@ -24,8 +24,8 @@ class ParsingError(errors.BasicException):
     pass
 
 
-class DirectoryExistsException(errors.BasicException):
-    """directory already exists"""
+class ConfigurationExistsException(errors.BasicException):
+    """configuration file already exists; use --force to overwrite"""
     pass
 
 
@@ -59,14 +59,15 @@ def load(conf_path):
     _params = _purify(_params)
 
 
-def generate(conf_path):
+def generate(conf_path, force):
     """Generates new configuration file using defaults."""
     global _path
     _path = os.path.join(os.path.abspath(conf_path), const.CONF_NAME)
 
-    if os.path.isdir(site_dir()):
-        raise DirectoryExistsException(path=site_dir())
-    else:
+    if not force and os.path.exists(_path):
+        raise ConfigurationExistsException(path=_path)
+
+    if not os.path.isdir(site_dir()):
         os.makedirs(site_dir())
 
     header = "# %s\n\n" % const.CONF_HEADER
@@ -138,8 +139,14 @@ def theme_assets_dir():
     return theme_dir('theme/assets')
 
 
-def theme_templates_dir():
-    return theme_dir('theme/templates')
+def theme_templates_dir(relative=False):
+    result = theme_dir('theme/templates')
+    use_rel = relative and result.startswith(site_dir())
+    return os.path.relpath(result, site_dir()) if use_rel else result
+
+
+def data_dir(append=False):
+    return site_dir(os.path.join('data', append or ''))
 
 
 def tags_rel_url():
@@ -246,7 +253,7 @@ def _purify(params):
 def _expand(rel_path):
     """Expands relative path using configuration file location as base
     directory. Absolute pathes will be returned as is."""
-    path = rel_path
+    path = os.path.expandvars(os.path.expanduser(rel_path))
     if not os.path.isabs(path):
         base = os.path.dirname(os.path.abspath(_path))
         path = os.path.join(base, path)
